@@ -74,7 +74,7 @@ def install(use_defaults,
     """
     utils.confirm_mode()
 
-    apt_deps = 'libssl-dev libffi-dev'
+    apt_deps = 'curl net-tools libssl-dev libffi-dev'
     user = utils.getenv('USER')
     default_dir = path.abspath('./brewblox')
 
@@ -165,7 +165,7 @@ def install(use_defaults,
     # Install docker-compose
     if docker_compose_install:
         utils.info('Installing docker-compose...')
-        sh('sudo {} -m pip install -U docker-compose'.format(const.PY))
+        utils.pip_install('docker-compose')
     else:
         utils.info('Skipped: docker-compose install.')
 
